# Brainsprite
Brainsprite is a library to incorporate interactive brain viewers in html web documents. Brainsprite is composed of two components: a javascript rendering engine, and a python API used to populate an html template with all necessary data and meta data. The documentation of the project can be found on https://brainsprite.github.io 

[![CircleCI](https://circleci.com/gh/brainsprite/brainsprite.svg?style=svg)](https://circleci.com/gh/brainsprite/brainsprite) [![Codacy Badge](https://api.codacy.com/project/badge/Grade/8ad58f155f3544209fa01fb4ed87eadc)](https://www.codacy.com/gh/brainsprite/brainsprite?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=brainsprite/brainsprite&amp;utm_campaign=Badge_Grade) [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT) [![collaborate brainhack](https://img.shields.io/badge/collaborate-brainhack-FF69A4.svg)](https://mattermost.brainhack.org/brainhack/channels/brainsprite)
